@@ -25,15 +25,32 @@
  * $Name:  $
  */
 
-#ifndef MOSES_H
-#define MOSES_H
+#ifndef FORS_OVERSCAN_H
+#define FORS_OVERSCAN_H
 
 #include <cpl.h>
+#include "fiera_config.h"
+#include "fors_image.h"
 
-CPL_BEGIN_DECLS
 
-cpl_image * fors_remove_overscan(cpl_image * image, cpl_propertylist * header);
+fors_image * fors_subtract_prescan(const fors_image * image, 
+                                   const mosca::ccd_config& ccd_config);
 
-CPL_END_DECLS
+fors_image_list * fors_subtract_prescan(const fors_image_list * ima_list, 
+                                        const mosca::ccd_config& ccd_config);
+
+void fors_trimm_preoverscan(fors_image * image, 
+                            const mosca::ccd_config& ccd_config);
+
+void fors_trimm_preoverscan(fors_image_list * ima_list, 
+                            const mosca::ccd_config& ccd_config);
+
+void fors_trimm_preoverscan(cpl_mask *& mask, 
+                            const mosca::ccd_config& ccd_config);
+
+void fors_trimm_fill_info(cpl_propertylist * header,
+                          const mosca::ccd_config& ccd_config);
+
+void fors_trimm_fix_wcs(cpl_propertylist * header);
 
 #endif   /* FORS_OVERSCAN_H */
